pub enum Error {
BufferExhausted,
InvalidInput,
ErrorDetectionCode,
Other,
}Expand description
Common transmit/receive errors. This list is intended to grow over time and it is not recommended to exhaustively match against it.
Variants
BufferExhausted
In case of transmissions: Buffer full. In case of reception: Buffer empty.
InvalidInput
ErrorDetectionCode
A reception can fail with this error if it’s grounded in the parity checking, CRC calculation or similar.
Other